==> fop_0.93.dfsg.1.orig.tar.gz: fop-0.93.dfsg.1.orig/src/java/org/apache/fop/fo/extensions/xmp/RDFElement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */

package org.apache.fop.fo.extensions.xmp;

import org.apache.fop.fo.FONode;
import org.apache.xmlgraphics.xmp.XMPConstants;

/**
 * Represents the top-level "RDF" element used by XMP metadata.
 */
public class RDFElement extends AbstractMetadataElement {

    /**
     * Main constructor.
     * @param parent the parent formatting object
     */
    public RDFElement(FONode parent) {
        super(parent);
    }
    
    /** @see org.apache.fop.fo.FONode#getLocalName() */
    public String getLocalName() {
        return "RDF";
    }

    /** @see org.apache.fop.fo.FONode#getNormalNamespacePrefix() */
    public String getNormalNamespacePrefix() {
        return "rdf";
    }

    /** @see org.apache.fop.fo.FONode#getNamespaceURI() */
    public String getNamespaceURI() {
        return XMPConstants.RDF_NAMESPACE;
    }

}

==> fop_0.95.dfsg.orig.tar.gz: fop-0.95/src/java/org/apache/fop/fo/extensions/xmp/RDFElement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: RDFElement.java 627367 2008-02-13 12:03:30Z maxberger $ */

package org.apache.fop.fo.extensions.xmp;

import org.apache.fop.fo.FONode;
import org.apache.xmlgraphics.xmp.XMPConstants;

/**
 * Represents the top-level "RDF" element used by XMP metadata.
 */
public class RDFElement extends AbstractMetadataElement {

    /**
     * Main constructor.
     * @param parent the parent formatting object
     */
    public RDFElement(FONode parent) {
        super(parent);
    }
    
    /** {@inheritDoc} */
    public String getLocalName() {
        return "RDF";
    }

    /** {@inheritDoc} */
    public String getNormalNamespacePrefix() {
        return "rdf";
    }

    /** {@inheritDoc} */
    public String getNamespaceURI() {
        return XMPConstants.RDF_NAMESPACE;
    }

}
